<?php

/**
  ReduxFramework Sample Config File
  For full documentation, please visit: https://docs.reduxframework.com
 * */

if (!class_exists('Road_Theme_Config')) {

    class Road_Theme_Config {

        public $args        = array();
        public $sections    = array();
        public $theme;
        public $ReduxFramework;

        public function __construct() {

            if (!class_exists('ReduxFramework')) {
                return;
            }

            // This is needed. Bah WordPress bugs.  ;)
            if (  true == Redux_Helpers::isTheme(__FILE__) ) {
                $this->initSettings();
            } else {
                add_action('plugins_loaded', array($this, 'initSettings'), 10);
            }

        }

        public function initSettings() {

            // Just for demo purposes. Not needed per say.
            $this->theme = wp_get_theme();

            // Set the default arguments
            $this->setArguments();

            // Set a few help tabs so you can see how it's done
            $this->setHelpTabs();

            // Create the sections and fields
            $this->setSections();

            if (!isset($this->args['opt_name'])) { // No errors please
                return;
            }

            // If Redux is running as a plugin, this will remove the demo notice and links
            //add_action( 'redux/loaded', array( $this, 'remove_demo' ) );
            
            // Function to test the compiler hook and demo CSS output.
            // Above 10 is a priority, but 2 in necessary to include the dynamically generated CSS to be sent to the function.
            //add_filter('redux/options/'.$this->args['opt_name'].'/compiler', array( $this, 'compiler_action' ), 10, 3);
            
            // Change the arguments after they've been declared, but before the panel is created
            //add_filter('redux/options/'.$this->args['opt_name'].'/args', array( $this, 'change_arguments' ) );
            
            // Change the default value of a field after it's been set, but before it's been useds
            //add_filter('redux/options/'.$this->args['opt_name'].'/defaults', array( $this,'change_defaults' ) );
            
            // Dynamically add a section. Can be also used to modify sections/fields
            //add_filter('redux/options/' . $this->args['opt_name'] . '/sections', array($this, 'dynamic_section'));

            $this->ReduxFramework = new ReduxFramework($this->sections, $this->args);
        }

        /**

          This is a test function that will let you see when the compiler hook occurs.
          It only runs if a field	set with compiler=>true is changed.

         * */
        function compiler_action($options, $css, $changed_values) {
            echo '<h1>The compiler hook has run!</h1>';
            echo "<pre>";
            print_r($changed_values); // Values that have changed since the last save
            echo "</pre>";
            //print_r($options); //Option values
            //print_r($css); // Compiler selector CSS values  compiler => array( CSS SELECTORS )

            /*
              // Demo of how to use the dynamic CSS and write your own static CSS file
              $filename = dirname(__FILE__) . '/style' . '.css';
              global $wp_filesystem;
              if( empty( $wp_filesystem ) ) {
                require_once( ABSPATH .'/wp-admin/includes/file.php' );
              WP_Filesystem();
              }

              if( $wp_filesystem ) {
                $wp_filesystem->put_contents(
                    $filename,
                    $css,
                    FS_CHMOD_FILE // predefined mode settings for WP files
                );
              }
             */
        }

        /**

          Custom function for filtering the sections array. Good for child themes to override or add to the sections.
          Simply include this function in the child themes functions.php file.

          NOTE: the defined constants for URLs, and directories will NOT be available at this point in a child theme,
          so you must use get_template_directory_uri() if you want to use any of the built in icons

         * */
        function dynamic_section($sections) {
            //$sections = array();
            $sections[] = array(
                'title' => __('Section via hook', 'roadthemes'),
                'desc' => __('<p class="description">This is a section created by adding a filter to the sections array. Can be used by child themes to add/remove sections from the options.</p>', 'roadthemes'),
                'icon' => 'el-icon-paper-clip',
                // Leave this as a blank section, no options just some intro text set above.
                'fields' => array()
            );

            return $sections;
        }

        /**

          Filter hook for filtering the args. Good for child themes to override or add to the args array. Can also be used in other functions.

         * */
        function change_arguments($args) {
            //$args['dev_mode'] = true;

            return $args;
        }

        /**

          Filter hook for filtering the default value of any given field. Very useful in development mode.

         * */
        function change_defaults($defaults) {
            $defaults['str_replace'] = 'Testing filter hook!';

            return $defaults;
        }

        // Remove the demo link and the notice of integrated demo from the redux-framework plugin
        function remove_demo() {

            // Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
            if (class_exists('ReduxFrameworkPlugin')) {
                remove_filter('plugin_row_meta', array(ReduxFrameworkPlugin::instance(), 'plugin_metalinks'), null, 2);

                // Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
                remove_action('admin_notices', array(ReduxFrameworkPlugin::instance(), 'admin_notices'));
            }
        }

        public function setSections() {

            /**
              Used within different fields. Simply examples. Search for ACTUAL DECLARATION for field examples
             * */
            // Background Patterns Reader
            $sample_patterns_path   = ReduxFramework::$_dir . '../sample/patterns/';
            $sample_patterns_url    = ReduxFramework::$_url . '../sample/patterns/';
            $sample_patterns        = array();

            if (is_dir($sample_patterns_path)) :

                if ($sample_patterns_dir = opendir($sample_patterns_path)) :
                    $sample_patterns = array();

                    while (( $sample_patterns_file = readdir($sample_patterns_dir) ) !== false) {

                        if (stristr($sample_patterns_file, '.png') !== false || stristr($sample_patterns_file, '.jpg') !== false) {
                            $name = explode('.', $sample_patterns_file);
                            $name = str_replace('.' . end($name), '', $sample_patterns_file);
                            $sample_patterns[]  = array('alt' => $name, 'img' => $sample_patterns_url . $sample_patterns_file);
                        }
                    }
                endif;
            endif;

            ob_start();

            $ct             = wp_get_theme();
            $this->theme    = $ct;
            $item_name      = $this->theme->get('Name');
            $tags           = $this->theme->Tags;
            $screenshot     = $this->theme->get_screenshot();
            $class          = $screenshot ? 'has-screenshot' : '';

            $customize_title = sprintf(__('Customize &#8220;%s&#8221;', 'roadthemes'), $this->theme->display('Name'));
            
            ?>
            <div id="current-theme" class="<?php echo esc_attr($class); ?>">
            <?php if ($screenshot) : ?>
                <?php if (current_user_can('edit_theme_options')) : ?>
                        <a href="<?php echo wp_customize_url(); ?>" class="load-customize hide-if-no-customize" title="<?php echo esc_attr($customize_title); ?>">
                            <img src="<?php echo esc_url($screenshot); ?>" alt="<?php esc_attr_e('Current theme preview', 'roadthemes'); ?>" />
                        </a>
                <?php endif; ?>
                    <img class="hide-if-customize" src="<?php echo esc_url($screenshot); ?>" alt="<?php esc_attr_e('Current theme preview', 'roadthemes'); ?>" />
                <?php endif; ?>

                <h4><?php echo $this->theme->display('Name'); ?></h4>

                <div>
                    <ul class="theme-info">
                        <li><?php printf(__('By %s', 'roadthemes'), $this->theme->display('Author')); ?></li>
                        <li><?php printf(__('Version %s', 'roadthemes'), $this->theme->display('Version')); ?></li>
                        <li><?php echo '<strong>' . __('Tags', 'roadthemes') . ':</strong> '; ?><?php printf($this->theme->display('Tags')); ?></li>
                    </ul>
                    <p class="theme-description"><?php echo $this->theme->display('Description'); ?></p>
            <?php
            if ($this->theme->parent()) {
                printf(' <p class="howto">' . __('This <a href="%1$s">child theme</a> requires its parent theme, %2$s.','roadthemes') . '</p>', __('http://codex.wordpress.org/Child_Themes', 'roadthemes'), $this->theme->parent()->display('Name'));
            }
            ?>

                </div>
            </div>

            <?php
            $item_info = ob_get_contents();

            ob_end_clean();

            $sampleHTML = '';
            if (file_exists(dirname(__FILE__) . '/info-html.html')) {
                Redux_Functions::initWpFilesystem();
                
                global $wp_filesystem;

                $sampleHTML = $wp_filesystem->get_contents(dirname(__FILE__) . '/info-html.html');
            }
	
            // General
            $this->sections[] = array(
                'title'     => __('General', 'roadthemes'),
                'desc'      => __('General theme options', 'roadthemes'),
                'icon'      => 'el-icon-cog',
                'fields'    => array(

                    array(
                        'id'        => 'logo_main',
                        'type'      => 'media',
                        'title'     => __('Logo', 'roadthemes'),
                        'compiler'  => 'true',
                        'mode'      => false,
                        'desc'      => __('Upload logo here.', 'roadthemes'),
                    ),
					array(
                        'id'        => 'opt-favicon',
                        'type'      => 'media',
                        'title'     => __('Favicon', 'roadthemes'),
                        'compiler'  => 'true',
                        'mode'      => false,
                        'desc'      => __('Upload favicon here.', 'roadthemes'),
                    ),
					array(
                        'id'        => 'image_error',
                        'type'      => 'media',
                        'title'     => __('Image 404', 'roadthemes'),
						'subtitle'     => __('Image for error 404 page', 'roadthemes'),
                        'compiler'  => 'true',
                        'mode'      => false,
                    ),
                ),
            );
			// Background
            $this->sections[] = array(
                'title'     => __('Background', 'roadthemes'),
                'desc'      => __('Use this section to upload background images, select background color', 'roadthemes'),
                'icon'      => 'el-icon-picture',
                'fields'    => array(
					array(
                        'id'        => 'background_opt',
                        'type'      => 'background',
                        'output'    => array('body'),
                        'title'     => __('Body Background', 'roadthemes'),
                        'subtitle'  => __('Body background with image, color. Only work with box layout', 'roadthemes'),
						'default'   => '#ffffff',
                    ),
					array(
                        'id'        => 'blog_header',
                        'type'      => 'background',
                        'output'    => array('.blog_header'),
                        'title'     => __('Blog header background', 'roadthemes'),
						'default'   => '#eee',
                    ),
					array(
                        'id'        => 'about_header',
                        'type'      => 'background',
                        'output'    => array('.about_header'),
                        'title'     => __('About header background', 'roadthemes'),
						'default'   => '#eee',
                    ),
					array(
                        'id'        => 'contact_header',
                        'type'      => 'background',
                        'output'    => array('.contact-page .entry-header'),
                        'title'     => __('Contact header background', 'roadthemes'),
						'default'   => '#eee',
                    ),
                ),
            );
			// Colors
            $this->sections[] = array(
                'title'     => __('Colors', 'roadthemes'),
                'desc'      => __('Color options', 'roadthemes'),
                'icon'      => 'el-icon-tint',
                'fields'    => array(
					array(
                        'id'        => 'primary_color',
                        'type'      => 'color',
                        'title'     => __('Primary Color', 'roadthemes'),
                        'subtitle'  => __('Pick a color for primary color (default: #009587).', 'roadthemes'),
						'transparent' => false,
                        'default'   => '#009587',
                        'validate'  => 'color',
                    ),
					
					array(
                        'id'        => 'sale_color',
                        'type'      => 'color',
                        //'output'    => array(),
                        'title'     => __('Sale Label BG Color', 'roadthemes'),
                        'subtitle'  => __('Pick a color for bg sale label (default: #222222).', 'roadthemes'),
						'transparent' => false,
                        'default'   => '#222222',
                        'validate'  => 'color',
                    ),
					
					array(
                        'id'        => 'saletext_color',
                        'type'      => 'color',
                        //'output'    => array(),
                        'title'     => __('Sale Label Text Color', 'roadthemes'),
                        'subtitle'  => __('Pick a color for sale label text (default: #ffffff).', 'roadthemes'),
						'transparent' => false,
                        'default'   => '#ffffff',
                        'validate'  => 'color',
                    ),
					
					array(
                        'id'        => 'rate_color',
                        'type'      => 'color',
                        //'output'    => array(),
                        'title'     => __('Rating Star Color', 'roadthemes'),
                        'subtitle'  => __('Pick a color for star of rating (default: #ffe117).', 'roadthemes'),
						'transparent' => false,
                        'default'   => '#ffe117',
                        'validate'  => 'color',
                    ),
                ),
            );
			
			//Header
			$this->sections[] = array(
                'title'     => __('Header', 'roadthemes'),
                'desc'      => __('Header options', 'roadthemes'),
                'icon'      => 'el-icon-tasks',
                'fields'    => array(

					array(
                        'id'        => 'header_layout',
                        'type'      => 'select',
                        'title'     => __('Header Layout', 'roadthemes'),
                        'customizer_only'   => false,

                        //Must provide key => value pairs for select options
                        'options'   => array(
                            'default' => 'Default',
                            'second' => 'Second',
							'third' => 'Third',
							'fourth' => 'Fourth',
							'fifth' => 'Fifth',
							'ninth' => 'Ninth',
							'tenth' => 'Tenth',
                        ),
                        'default'   => 'default'
                    ),
					array(
                        'id'        => 'header_email',
                        'type'      => 'text',
                        'title'     => __('Email', 'roadthemes'),
                        'default'   => 'info@roadthemes.com'
                    ),
					array(
                        'id'        => 'header_phone',
                        'type'      => 'text',
                        'title'     => __('Phone', 'roadthemes'),
                        'default'   => '0987. 654. 321'
                    ),
					array(
                        'id'        => 'header_message',
                        'type'      => 'text',
                        'title'     => __('message', 'roadthemes'),
                        'default'   => 'welcome roadthemes'
                    ),
					array(
						'id'       => 'header_menu',
						'type'     => 'select',
						'data'     => 'menus',
						'title'    => __( 'Top Menu', 'roadthemes' ),
						'subtitle' => __( 'Select a menu', 'roadthemes' ),
					),
					array(
                        'id'        => 'categories_menu_label',
                        'type'      => 'text',
                        'title'     => __('Categories menu label', 'roadthemes'),
						'subtitle'     => __('The label for categories menu', 'roadthemes'),
                        'default'   => 'Category'
                    ),
					array(
						'id'        => 'categories_menu_items',
						'type'      => 'slider',
						'title'     => __('Number of items', 'roadthemes'),
						'desc'      => __('Number of menu items level 1 to show, default value: 8', 'roadthemes'),
						"default"   => 8,
						"min"       => 1,
						"step"      => 1,
						"max"       => 30,
						'display_value' => 'text'
					),
					array(
                        'id'        => 'categories_more_label',
                        'type'      => 'text',
                        'title'     => __('More Categories label', 'roadthemes'),
						'subtitle'     => __('The label for more categories button', 'roadthemes'),
                        'default'   => 'More Categories'
                    ),
					array(
                        'id'        => 'categories_less_label',
                        'type'      => 'text',
                        'title'     => __('Less Categories label', 'roadthemes'),
						'subtitle'     => __('The label for less categories button', 'roadthemes'),
                        'default'   => 'Close Menu'
                    ),
					array(
                        'id'        => 'categories_menu_home',
                        'type'      => 'switch',
                        'title'     => __('Home Categories Menu', 'roadthemes'),
						'subtitle'     => __('Always show categories menu on home page', 'roadthemes'),
						'default'   => true,
                    ),
					array(
                        'id'        => 'categories_menu_sub',
                        'type'      => 'switch',
                        'title'     => __('Inner Categories Menu', 'roadthemes'),
						'subtitle'     => __('Always show categories menu on inner pages', 'roadthemes'),
						'default'   => false,
                    ),
					array(
                        'id'        => 'mobile_menu_label',
                        'type'      => 'text',
                        'title'     => __('Mobile menu label', 'roadthemes'),
						'subtitle'     => __('The label for mobile menu (example: Menu, Go to...', 'roadthemes'),
                        'default'   => 'Menu'
                    ),
					array(
                        'id'        => 'header_bg',
                        'type'      => 'color',
                        'title'     => __('Header Background', 'roadthemes'),
                        'subtitle'  => __('Select background color for header (default: #2f2f2f).', 'roadthemes'),
						'transparent' => true,
                        'default'   => '#2f2f2f',
                        'validate'  => 'color',
                    ),
					array(
                        'id'        => 'nav_bg',
                        'type'      => 'color',
                        'title'     => __('Navigator Background', 'roadthemes'),
                        'subtitle'  => __('Select background color for navigator (default: #313131).', 'roadthemes'),
						'transparent' => true,
                        'default'   => '#313131',
                        'validate'  => 'color',
                    ),
                ),
            );
			
			//Footer
			$this->sections[] = array(
                'title'     => __('Footer', 'roadthemes'),
                'desc'      => __('Footer options', 'roadthemes'),
                'icon'      => 'el-icon-cog',
                'fields'    => array(

					array(
						'id'               => 'copyright',
						'type'             => 'editor',
						'title'    => __('Copyright information', 'roadthemes'),
						'subtitle'         => __('HTML tags allowed: a, br, em, strong', 'roadthemes'),
						'default'          => 'Copyright Roadthemes 2014. All Rights Reserved',
						'args'   => array(
							'teeny'            => true,
							'textarea_rows'    => 5,
							'media_buttons'	=> false,
						)
					),
					array(
						'id'               => 'payment_icons',
						'type'             => 'editor',
						'title'    => __('Payment icons', 'roadthemes'),
						'subtitle'         => __('HTML tags allowed: a, img', 'roadthemes'),
						'default'          => '',
						'args'   => array(
							'teeny'            => true,
							'textarea_rows'    => 5,
							'media_buttons'	=> true,
						)
					),
                ),
            );
			$this->sections[] = array(
				'icon'       => 'el-icon-website',
				'title'      => __( 'Newsletter', 'roadthemes' ),
				'subsection' => true,
				'fields'     => array(
					array(
                        'id'        => 'newsletter_title',
                        'type'      => 'text',
                        'title'     => __('Newsletter title', 'roadthemes'),
                        'default'   => 'Newsletter'
                    ),
					array(
						'id'       => 'newsletter_form',
						'type'     => 'text',
						'title'    => __('Newsletter form ID', 'roadthemes'),
						'subtitle' => __('The form ID of MailPoet plugin.', 'roadthemes'),
						'validate' => 'numeric',
						'msg'      => 'Please enter a form ID',
						'default'  => '1'
					),
				)
			);
			$this->sections[] = array(
				'icon'       => 'el-icon-website',
				'title'      => __( 'Social Icons', 'roadthemes' ),
				'subsection' => true,
				'fields'     => array(
					 
					array(
						'id'       => 'social_icons',
						'type'     => 'sortable',
						'title'    => __('Social Icons', 'roadthemes'),
						'subtitle' => __('Enter social links', 'roadthemes'),
						'desc'     => __('Drag/drop to re-arrange', 'roadthemes'),
						'mode'     => 'text',
						'options'  => array(
							'facebook'     => '',
							'twitter'     => '',
							'instagram'     => '',
							'tumblr'     => '',
							'pinterest'     => '',
							'google-plus'     => '',
							'linkedin'     => '',
							'behance'     => '',
							'dribbble'     => '',
							'youtube'     => '',
							'vimeo'     => '',
							'rss'     => '',
						),
						'default' => array(
						    'facebook'     => 'https://www.facebook.com/',
							'twitter'     => 'https://twitter.com/',
							'tumblr'     => 'https://www.tumblr.com/',
							'pinterest'     => '',
							'google-plus'     => 'https://plus.google.com/',
							'linkedin'     => '',
							'behance'     => '',
							'dribbble'     => 'https://dribbble.com/',
							'youtube'     => '',
							'vimeo'     => '',
							'rss'     => '',
						),
					),
				)
			);
			$this->sections[] = array(
				'icon'       => 'el-icon-website',
				'title'      => __( 'Contact Us', 'roadthemes' ),
				'subsection' => true,
				'fields'     => array(
					array(
                        'id'        => 'contact_title',
                        'type'      => 'text',
                        'title'     => __('Contact Us title', 'roadthemes'),
                        'default'   => 'Contact Us'
                    ),
					array(
						'id'=>'contact_us',
						'type' => 'textarea',
						'title' => __('Contact Us', 'roadthemes'), 
						'subtitle'         => __('HTML tags allowed: a, img, br, em, strong, p, ul, li', 'roadthemes'),
						'default' => '',
					),
				)
			);
			$this->sections[] = array(
				'icon'       => 'el-icon-website',
				'title'      => __( 'Menus', 'roadthemes' ),
				'subsection' => true,
				'fields'     => array(
					array(
						'id'       => 'footer_menu1',
						'type'     => 'select',
						'data'     => 'menus',
						'title'    => __( 'Menu #1', 'roadthemes' ),
						'subtitle' => __( 'Select a menu', 'roadthemes' ),
					),
					array(
						'id'       => 'footer_menu2',
						'type'     => 'select',
						'data'     => 'menus',
						'title'    => __( 'Menu #2', 'roadthemes' ),
						'subtitle' => __( 'Select a menu', 'roadthemes' ),
					),
					array(
						'id'       => 'footer_menu3',
						'type'     => 'select',
						'data'     => 'menus',
						'title'    => __( 'Menu #3', 'roadthemes' ),
						'subtitle' => __( 'Select a menu', 'roadthemes' ),
					),
					array(
						'id'       => 'footer_menu_bottom',
						'type'     => 'select',
						'data'     => 'menus',
						'title'    => __( 'Menu Bottom', 'roadthemes' ),
						'subtitle' => __( 'Select a menu', 'roadthemes' ),
					),
				)
			);
			
			//Fonts
			$this->sections[] = array(
                'title'     => __('Fonts', 'roadthemes'),
                'desc'      => __('Fonts options', 'roadthemes'),
                'icon'      => 'el-icon-font',
                'fields'    => array(

                    array(
                        'id'            => 'bodyfont',
                        'type'          => 'typography',
                        'title'         => __('Body font', 'roadthemes'),
                        //'compiler'      => true,  // Use if you want to hook in your own CSS compiler
                        'google'        => true,    // Disable google fonts. Won't work if you haven't defined your google api key
                        'font-backup'   => true,    // Select a backup non-google font in addition to a google font
                        //'font-style'    => false, // Includes font-style and weight. Can use font-style or font-weight to declare
                        'subsets'       => false, // Only appears if google is true and subsets not set to false
						'text-align'   => false,
                        //'font-size'     => false,
                        //'line-height'   => false,
                        //'word-spacing'  => true,  // Defaults to false
                        //'letter-spacing'=> true,  // Defaults to false
                        //'color'         => false,
                        //'preview'       => false, // Disable the previewer
                        'all_styles'    => true,    // Enable all Google Font style/weight variations to be added to the page
                        'output'        => array('body'), // An array of CSS selectors to apply this font style to dynamically
                        //'compiler'      => array('h2.site-description-compiler'), // An array of CSS selectors to apply this font style to dynamically
                        'units'         => 'px', // Defaults to px
                        'subtitle'      => __('Main body font.', 'roadthemes'),
                        'default'       => array(
                            'color'         => '#222',
                            'font-weight'    => '400',
                            'font-family'   => 'Open Sans',
                            'google'        => true,
                            'font-size'     => '13px',
                            'line-height'   => '20px'),
                    ),
					array(
                        'id'            => 'headingfont',
                        'type'          => 'typography',
                        'title'         => __('Heading font', 'roadthemes'),
                        //'compiler'      => true,  // Use if you want to hook in your own CSS compiler
                        'google'        => true,    // Disable google fonts. Won't work if you haven't defined your google api key
                        'font-backup'   => false,    // Select a backup non-google font in addition to a google font
                        //'font-style'    => false, // Includes font-style and weight. Can use font-style or font-weight to declare
                        'subsets'       => false, // Only appears if google is true and subsets not set to false
                        'font-size'     => false,
                        'line-height'   => false,
						'text-align'   => false,
                        //'word-spacing'  => true,  // Defaults to false
                        //'letter-spacing'=> true,  // Defaults to false
                        //'color'         => false,
                        //'preview'       => false, // Disable the previewer
                        'all_styles'    => true,    // Enable all Google Font style/weight variations to be added to the page
                        //'output'        => array('h1, h2, h3, h4, h5, h6'), // An array of CSS selectors to apply this font style to dynamically
                        //'compiler'      => array('h2.site-description-compiler'), // An array of CSS selectors to apply this font style to dynamically
                        'units'         => 'px', // Defaults to px
                        'subtitle'      => __('Heading font.', 'roadthemes'),
                        'default'       => array(
                            'color'         => '#4c4c4c',
                            'font-weight'    => '700',
                            'font-family'   => 'Montserrat',
                            'google'        => true,
						),
                    ),
					array(
                        'id'            => 'menufont',
                        'type'          => 'typography',
                        'title'         => __('Menu font', 'roadthemes'),
                        //'compiler'      => true,  // Use if you want to hook in your own CSS compiler
                        'google'        => true,    // Disable google fonts. Won't work if you haven't defined your google api key
                        'font-backup'   => false,    // Select a backup non-google font in addition to a google font
                        //'font-style'    => false, // Includes font-style and weight. Can use font-style or font-weight to declare
                        'subsets'       => false, // Only appears if google is true and subsets not set to false
                        'font-size'     => false,
                        'line-height'   => false,
						'text-align'   => false,
                        //'word-spacing'  => true,  // Defaults to false
                        //'letter-spacing'=> true,  // Defaults to false
                        //'color'         => false,
                        //'preview'       => false, // Disable the previewer
                        'all_styles'    => true,    // Enable all Google Font style/weight variations to be added to the page
                        //'output'        => array('h1, h2, h3, h4, h5, h6'), // An array of CSS selectors to apply this font style to dynamically
                        //'compiler'      => array('h2.site-description-compiler'), // An array of CSS selectors to apply this font style to dynamically
                        'units'         => 'px', // Defaults to px
                        'subtitle'      => __('Menu font.', 'roadthemes'),
                        'default'       => array(
                            'color'         => '#ffffff',
                            'font-style'    => '700',
                            'font-family'   => 'Montserrat',
                            'google'        => true,
						),
                    ),
                ),
            );
			
			// Layout
            $this->sections[] = array(
                'title'     => __('Layout', 'roadthemes'),
                'desc'      => __('Select page layout: Box or Full Width', 'roadthemes'),
                'icon'      => 'el-icon-align-justify',
                'fields'    => array(
					array(
						'id'       => 'page_layout',
						'type'     => 'select',
						'multi'    => false,
						'title'    => __('Page Layout', 'roadthemes'),
						'options'  => array(
							'full' => 'Full Width',
							'box' => 'Box'
						),
						'default'  => 'full'
					),
					array(
                        'id'        => 'preset_option',
                        'type'      => 'select',
                        'title'     => __('Preset', 'roadthemes'),
						'subtitle'      => __('Select a preset to quickly apply pre-defined colors and fonts', 'roadthemes'),
                        'customizer_only'   => false,
                        'options'   => array(
							'1' => 'Use options',
                            '2' => 'Preset 2',
							'3' => 'Preset 3',
							'4' => 'Preset 4',
							'5' => 'Preset 5',
							'6' => 'Preset 6',
							'7' => 'Preset 7',
							'9' => 'Preset 9',
							'10' => 'Preset 10',
                        ),
                        'default'   => '1'
                    ),
					array(
                        'id'        => 'enable_sswitcher',
                        'type'      => 'switch',
                        'title'     => __('Show Style Switcher', 'roadthemes'),
						'subtitle'     => __('The style switcher is only for preview on front-end', 'roadthemes'),
						'default'   => false,
                    ),
                ),
            );
			
			//Brand logos
			$this->sections[] = array(
                'title'     => __('Brand Logos', 'roadthemes'),
                'desc'      => __('Upload brand logos and links', 'roadthemes'),
                'icon'      => 'el-icon-briefcase',
                'fields'    => array(
					array(
                        'id'        => 'brand_title',
                        'type'      => 'text',
                        'title'     => __('Brand title', 'roadthemes'),
                        'default'   => 'Our Brands'
                    ),
					array(
						'id'        => 'brandnumber',
						'type'      => 'slider',
						'title'     => __('Number of logos per page', 'roadthemes'),
						'desc'      => __('Number of logos per page, default value: 6', 'roadthemes'),
						"default"   => 6,
						"min"       => 1,
						"step"      => 1,
						"max"       => 12,
						'display_value' => 'text'
					),
					array(
						'id'       => 'brandscroll',
						'type'     => 'switch',
						'title'    => __('Auto scroll', 'roadthemes'),
						'default'  => true,
					),
					array(
						'id'        => 'brandscrollnumber',
						'type'      => 'slider',
						'title'     => __('Scroll amount', 'roadthemes'),
						'desc'      => __('Number of logos to scroll one time, default value: 2', 'roadthemes'),
						"default"   => 2,
						"min"       => 1,
						"step"      => 1,
						"max"       => 12,
						'display_value' => 'text'
					),
					array(
						'id'        => 'brandpause',
						'type'      => 'slider',
						'title'     => __('Pause in (seconds)', 'roadthemes'),
						'desc'      => __('Pause time, default value: 3000', 'roadthemes'),
						"default"   => 3000,
						"min"       => 1000,
						"step"      => 500,
						"max"       => 10000,
						'display_value' => 'text'
					),
					array(
						'id'        => 'brandanimate',
						'type'      => 'slider',
						'title'     => __('Animate in (seconds)', 'roadthemes'),
						'desc'      => __('Animate time, default value: 2000', 'roadthemes'),
						"default"   => 2000,
						"min"       => 300,
						"step"      => 100,
						"max"       => 5000,
						'display_value' => 'text'
					),
					array(
						'id'          => 'brand_logos',
						'type'        => 'slides',
						'title'       => __('Logos', 'roadthemes'),
						'desc'        => __('Upload logo image and enter logo link.', 'roadthemes'),
						'placeholder' => array(
							'title'           => __('Title', 'roadthemes'),
							'description'     => __('Description', 'roadthemes'),
							'url'             => __('Link', 'roadthemes'),
						),
					),
                ),
            );
			
			// Sidebar
			$this->sections[] = array(
                'title'     => __('Sidebar', 'roadthemes'),
                'desc'      => __('Sidebar options', 'roadthemes'),
                'icon'      => 'el-icon-cog',
                'fields'    => array(
					array(
						'id'       => 'sidebar_pos',
						'type'     => 'radio',
						'title'    => __('Main Sidebar Position', 'roadthemes'),
						'subtitle'      => __('Sidebar on category page', 'roadthemes'),
						'options'  => array(
							'left' => 'Left',
							'right' => 'Right'),
						'default'  => 'left'
					),
					array(
						'id'       => 'sidebarse_pos',
						'type'     => 'radio',
						'title'    => __('Secondary Sidebar Position', 'roadthemes'),
						'subtitle'      => __('Sidebar on pages', 'roadthemes'),
						'options'  => array(
							'left' => 'Left',
							'right' => 'Right'),
						'default'  => 'left'
					),
					array(
						'id'       => 'sidebarblog_pos',
						'type'     => 'radio',
						'title'    => __('Blog Sidebar Position', 'roadthemes'),
						'subtitle'      => __('Sidebar on Blog pages', 'roadthemes'),
						'options'  => array(
							'left' => 'Left',
							'right' => 'Right'),
						'default'  => 'right'
					),
                ),
            );
			
			// Portfolio
            $this->sections[] = array(
                'title'     => __('Portfolio', 'roadthemes'),
                'desc'      => __('Use this section to select options for portfolio', 'roadthemes'),
                'icon'      => 'el-icon-bookmark',
                'fields'    => array(
					array(
						'id'        => 'portfolio_columns',
						'type'      => 'slider',
						'title'     => __('Portfolio Columns', 'roadthemes'),
						"default"   => 3,
						"min"       => 2,
						"step"      => 1,
						"max"       => 4,
						'display_value' => 'text'
					),
					array(
						'id'        => 'portfolio_per_page',
						'type'      => 'slider',
						'title'     => __('Projects per page', 'roadthemes'),
						'desc'      => __('Amount of projects per page on portfolio page', 'roadthemes'),
						"default"   => 12,
						"min"       => 4,
						"step"      => 1,
						"max"       => 48,
						'display_value' => 'text'
					),
					array(
                        'id'        => 'related_project_title',
                        'type'      => 'text',
                        'title'     => __('Related projects title', 'roadthemes'),
                        'default'   => 'Related Projects'
                    ),
                ),
            );
			
			// Product
            $this->sections[] = array(
                'title'     => __('Product', 'roadthemes'),
                'desc'      => __('Use this section to select options for product', 'roadthemes'),
                'icon'      => 'el-icon-tags',
                'fields'    => array(
					array(
                        'id'        => 'shop_layout',
                        'type'      => 'select',
                        'title'     => __('Shop Layout', 'roadthemes'),
                        'customizer_only'   => false,
                        'options'   => array(
							'sidebar' => 'Sidebar',
                            'fullwidth' => 'Full Width',
                        ),
                        'default'   => 'sidebar'
                    ),
					array(
                        'id'        => 'default_view',
                        'type'      => 'select',
                        'title'     => __('Shop default view', 'roadthemes'),
                        'customizer_only'   => false,
                        'options'   => array(
							'grid-view' => 'Grid View',
                            'list-view' => 'List View',
                        ),
                        'default'   => 'grid-view'
                    ),
					array(
						'id'        => 'product_per_page',
						'type'      => 'slider',
						'title'     => __('Products per page', 'roadthemes'),
						'subtitle'      => __('Amount of products per page on category page', 'roadthemes'),
						"default"   => 12,
						"min"       => 4,
						"step"      => 4,
						"max"       => 48,
						'display_value' => 'text'
					),
					array(
						'id'        => 'product_per_row',
						'type'      => 'slider',
						'title'     => __('Product columns', 'roadthemes'),
						'subtitle'      => __('Amount of product columns on category page', 'roadthemes'),
						'desc'      => __('Only works with: 1, 2, 3, 4, 6', 'roadthemes'),
						"default"   => 3,
						"min"       => 1,
						"step"      => 1,
						"max"       => 6,
						'display_value' => 'text'
					),
					array(
						'id'        => 'product_per_row_fw',
						'type'      => 'slider',
						'title'     => __('Product columns on full width shop', 'roadthemes'),
						'subtitle'      => __('Amount of product columns on full width category page', 'roadthemes'),
						'desc'      => __('Only works with: 1, 2, 3, 4, 6', 'roadthemes'),
						"default"   => 4,
						"min"       => 1,
						"step"      => 1,
						"max"       => 6,
						'display_value' => 'text'
					),
					array(
						'id'       => 'second_image',
						'type'     => 'switch',
						'title'    => __('Use secondary product image', 'roadthemes'),
						'default'  => false,
					),
					array(
                        'id'        => 'related_title',
                        'type'      => 'text',
                        'title'     => __('Related products title', 'roadthemes'),
                        'default'   => 'Related Products'
                    ),
					array(
						'id'        => 'related_amount',
						'type'      => 'slider',
						'title'     => __('Number of related products', 'roadthemes'),
						"default"   => 6,
						"min"       => 4,
						"step"      => 1,
						"max"       => 16,
						'display_value' => 'text'
					),
					array(
                        'id'        => 'upsells_title',
                        'type'      => 'text',
                        'title'     => __('Up-Sells title', 'roadthemes'),
                        'default'   => 'Up-Sells'
                    ),
					array(
                        'id'        => 'crosssells_title',
                        'type'      => 'text',
                        'title'     => __('Cross-Sells title', 'roadthemes'),
                        'default'   => 'Cross-Sells'
                    ),
					array(
                        'id'        => 'detail_link_text',
                        'type'      => 'text',
                        'title'     => __('View details text', 'roadthemes'),
                        'default'   => 'View details'
                    ),
					array(
                        'id'        => 'quickview_link_text',
                        'type'      => 'text',
                        'title'     => __('View all features text', 'roadthemes'),
						'desc'      => __('This is the text on quick view box', 'roadthemes'),
                        'default'   => 'See all features'
                    ),
					array(
						'id'=>'share_head_code',
						'type' => 'textarea',
						'title' => __('ShareThis/AddThis head tag', 'roadthemes'), 
						'desc' => __('Paste your ShareThis or AddThis head tag here', 'roadthemes'),
						'default' => '',
					),
					array(
						'id'=>'share_code',
						'type' => 'textarea',
						'title' => __('ShareThis/AddThis code', 'roadthemes'), 
						'desc' => __('Paste your ShareThis or AddThis code here', 'roadthemes'),
						'default' => ''
					),
                ),
            );
			
			// Blog options
            $this->sections[] = array(
                'title'     => __('Blog', 'roadthemes'),
                'desc'      => __('Use this section to select options for blog', 'roadthemes'),
                'icon'      => 'el-icon-file',
                'fields'    => array(
					 
					array(
                        'id'        => 'blog_header_text',
                        'type'      => 'text',
                        'title'     => __('Blog header text', 'roadthemes'),
                        'default'   => 'Blog'
                    ),
					array(
                        'id'        => 'blog_layout',
                        'type'      => 'select',
                        'title'     => __('Blog Layout', 'roadthemes'),
                        'customizer_only'   => false,
                        'options'   => array(
							'nosidebar' => 'No Sidebar',
							'sidebar' => 'Sidebar',
                            'fullwidth' => 'Full Width',
                        ),
                        'default'   => 'nosidebar'
                    ),
					array(
                        'id'        => 'readmore_text',
                        'type'      => 'text',
                        'title'     => __('Read more text', 'roadthemes'),
                        'default'   => 'read more'
                    ),
					array(
						'id'        => 'excerpt_length',
						'type'      => 'slider',
						'title'     => __('Excerpt length on blog page', 'roadthemes'),
						"default"   => 22,
						"min"       => 10,
						"step"      => 2,
						"max"       => 120,
						'display_value' => 'text'
					),
					array(
						'id'       => 'blogscroll',
						'type'     => 'switch',
						'title'    => __('Latest posts auto scroll', 'roadthemes'),
						'default'  => false,
					),
					array(
						'id'        => 'blogpause',
						'type'      => 'slider',
						'title'     => __('Pause in (seconds)', 'roadthemes'),
						'desc'      => __('Pause time, default value: 3000', 'roadthemes'),
						"default"   => 3000,
						"min"       => 1000,
						"step"      => 500,
						"max"       => 10000,
						'display_value' => 'text'
					),
					array(
						'id'        => 'bloganimate',
						'type'      => 'slider',
						'title'     => __('Animate in (seconds)', 'roadthemes'),
						'desc'      => __('Animate time, default value: 2000', 'roadthemes'),
						"default"   => 2000,
						"min"       => 300,
						"step"      => 100,
						"max"       => 5000,
						'display_value' => 'text'
					),
                ),
            );
			
			// Testimonials options
            $this->sections[] = array(
                'title'     => __('Testimonials', 'roadthemes'),
                'desc'      => __('Use this section to select options for Testimonials', 'roadthemes'),
                'icon'      => 'el-icon-comment',
                'fields'    => array(
					array(
						'id'       => 'testiscroll',
						'type'     => 'switch',
						'title'    => __('Auto scroll', 'roadthemes'),
						'default'  => false,
					),
					array(
						'id'        => 'testipause',
						'type'      => 'slider',
						'title'     => __('Pause in (seconds)', 'roadthemes'),
						'desc'      => __('Pause time, default value: 3000', 'roadthemes'),
						"default"   => 3000,
						"min"       => 1000,
						"step"      => 500,
						"max"       => 10000,
						'display_value' => 'text'
					),
					array(
						'id'        => 'testianimate',
						'type'      => 'slider',
						'title'     => __('Animate in (seconds)', 'roadthemes'),
						'desc'      => __('Animate time, default value: 2000', 'roadthemes'),
						"default"   => 2000,
						"min"       => 300,
						"step"      => 100,
						"max"       => 5000,
						'display_value' => 'text'
					),
                ),
            );
			
			// Contact Map
            $this->sections[] = array(
                'title'     => __('Contact Map', 'roadthemes'),
                'desc'      => __('Use this section to select options for Google Map on contact page', 'roadthemes'),
                'icon'      => 'el-icon-map-marker',
                'fields'    => array(
					array(
                        'id'        => 'enable_map',
                        'type'      => 'switch',
                        'title'     => __('Show map', 'roadthemes'),
						'subtitle'     => __('Show map on contact page', 'roadthemes'),
						'default'   => true,
                    ),
					array(
						'id'       => 'address_by',
						'type'     => 'radio',
						'title'    => __('Locate by', 'roadthemes'),
						'subtitle'      => __('Locate marker by address or coordinate', 'roadthemes'),
						'options'  => array(
							'address' => 'Address',
							'coordinate' => 'Coordinate'
						),
						'default'  => 'address'
					),
					array(
						'id'               => 'map_desc',
						'type'             => 'editor',
						'title'    => __('Map description', 'roadthemes'),
						'subtitle' => __('The text on map popup', 'roadthemes'),
						'default'          => '',
						'args'   => array(
							'teeny'            => true,
							'textarea_rows'    => 5,
							'media_buttons'	=> false,
						)
					),
					array(
						'id'               => 'map_custom_text',
						'type'             => 'editor',
						'title'    => __('Custom text', 'roadthemes'),
						'subtitle' => __('The custom text under the map', 'roadthemes'),
						'default'          => '',
						'args'   => array(
							'teeny'            => true,
							'textarea_rows'    => 5,
							'media_buttons'	=> false,
						)
					),
					array(
                        'id'        => 'map_lat',
                        'type'      => 'text',
                        'title'     => __('Latitude', 'roadthemes'),
                        'default'   => '51.50657'
                    ),
					array(
                        'id'        => 'map_long',
                        'type'      => 'text',
                        'title'     => __('Longtitude', 'roadthemes'),
                        'default'   => '-0.13408'
                    ),
					array(
                        'id'        => 'map_address',
                        'type'      => 'text',
                        'title'     => __('Address', 'roadthemes'),
                        'default'   => 'Pall Mall, London England'
                    ),
					array(
						'id'        => 'map_zoom',
						'type'      => 'slider',
						'title'     => __('Zoom level', 'roadthemes'),
						"default"   => 17,
						"min"       => 0,
						"step"      => 1,
						"max"       => 21,
						'display_value' => 'text'
					),
					array(
                        'id'        => 'map_marker',
                        'type'      => 'media',
                        'title'     => __('Marker', 'roadthemes'),
                        'compiler'  => 'true',
                        'mode'      => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc'      => __('Upload marker image here, the image size is 32x47 pixels.', 'roadthemes'),
                    ),
                ),
            );
			
			// Custom CSS
            $this->sections[] = array(
                'title'     => __('Custom CSS', 'roadthemes'),
                'desc'      => __('Add your Custom CSS code', 'roadthemes'),
                'icon'      => 'el-icon-pencil',
                'fields'    => array(
					array(
						'id'       => 'custom_css',
						'type'     => 'ace_editor',
						'title'    => __('CSS Code', 'roadthemes'),
						'subtitle' => __('Paste your CSS code here.', 'roadthemes'),
						'mode'     => 'css',
						'theme'    => 'monokai', //chrome
						'default'  => ""
					),
                ),
            );
			
			// Less Compiler
            $this->sections[] = array(
                'title'     => __('Less Compiler', 'roadthemes'),
                'desc'      => __('Turn on this option to apply all theme options. Turn of when you have finished changing theme options and your site is ready.', 'roadthemes'),
                'icon'      => 'el-icon-wrench',
                'fields'    => array(
					array(
                        'id'        => 'enable_less',
                        'type'      => 'switch',
                        'title'     => __('Enable Less Compiler', 'roadthemes'),
						'default'   => true,
                    ),
                ),
            );
			
            $theme_info  = '<div class="redux-framework-section-desc">';
            $theme_info .= '<p class="redux-framework-theme-data description theme-uri">' . __('<strong>Theme URL:</strong> ', 'roadthemes') . '<a href="' . $this->theme->get('ThemeURI') . '" target="_blank">' . $this->theme->get('ThemeURI') . '</a></p>';
            $theme_info .= '<p class="redux-framework-theme-data description theme-author">' . __('<strong>Author:</strong> ', 'roadthemes') . $this->theme->get('Author') . '</p>';
            $theme_info .= '<p class="redux-framework-theme-data description theme-version">' . __('<strong>Version:</strong> ', 'roadthemes') . $this->theme->get('Version') . '</p>';
            $theme_info .= '<p class="redux-framework-theme-data description theme-description">' . $this->theme->get('Description') . '</p>';
            $tabs = $this->theme->get('Tags');
            if (!empty($tabs)) {
                $theme_info .= '<p class="redux-framework-theme-data description theme-tags">' . __('<strong>Tags:</strong> ', 'roadthemes') . implode(', ', $tabs) . '</p>';
            }
            $theme_info .= '</div>';
           
            $this->sections[] = array(
                'title'     => __('Import / Export', 'roadthemes'),
                'desc'      => __('Import and Export your Redux Framework settings from file, text or URL.', 'roadthemes'),
                'icon'      => 'el-icon-refresh',
                'fields'    => array(
                    array(
                        'id'            => 'opt-import-export',
                        'type'          => 'import_export',
                        'title'         => 'Import Export',
                        'subtitle'      => 'Save and restore your Redux options',
                        'full_width'    => false,
                    ),
                ),
            );

            $this->sections[] = array(
                'icon'      => 'el-icon-info-sign',
                'title'     => __('Theme Information', 'roadthemes'),
                //'desc'      => __('<p class="description">This is the Description. Again HTML is allowed</p>', 'roadthemes'),
                'fields'    => array(
                    array(
                        'id'        => 'opt-raw-info',
                        'type'      => 'raw',
                        'content'   => $item_info,
                    )
                ),
            );
        }

        public function setHelpTabs() {

            // Custom page help tabs, displayed using the help API. Tabs are shown in order of definition.
            $this->args['help_tabs'][] = array(
                'id'        => 'redux-help-tab-1',
                'title'     => __('Theme Information 1', 'roadthemes'),
                'content'   => __('<p>This is the tab content, HTML is allowed.</p>', 'roadthemes')
            );

            $this->args['help_tabs'][] = array(
                'id'        => 'redux-help-tab-2',
                'title'     => __('Theme Information 2', 'roadthemes'),
                'content'   => __('<p>This is the tab content, HTML is allowed.</p>', 'roadthemes')
            );

            // Set the help sidebar
            $this->args['help_sidebar'] = __('<p>This is the sidebar content, HTML is allowed.</p>', 'roadthemes');
        }

        /**

          All the possible arguments for Redux.
          For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments

         * */
        public function setArguments() {

            $theme = wp_get_theme(); // For use with some settings. Not necessary.

            $this->args = array(
                // TYPICAL -> Change these values as you need/desire
                'opt_name'          => 'road_opt',            // This is where your data is stored in the database and also becomes your global variable name.
                'display_name'      => $theme->get('Name'),     // Name that appears at the top of your panel
                'display_version'   => $theme->get('Version'),  // Version that appears at the top of your panel
                'menu_type'         => 'menu',                  //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
                'allow_sub_menu'    => true,                    // Show the sections below the admin menu item or not
                'menu_title'        => __('Theme Options', 'roadthemes'),
                'page_title'        => __('Theme Options', 'roadthemes'),
                
                // You will need to generate a Google API key to use this feature.
                // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
                'google_api_key' => '', // Must be defined to add google fonts to the typography module
                
                'async_typography'  => true,                    // Use a asynchronous font on the front end or font string
                //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
                'admin_bar'         => true,                    // Show the panel pages on the admin bar
                'global_variable'   => '',                      // Set a different name for your global variable other than the opt_name
                'dev_mode'          => false,                    // Show the time the page took to load, etc
                'customizer'        => true,                    // Enable basic customizer support
                //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
                //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

                // OPTIONAL -> Give you extra features
                'page_priority'     => null,                    // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
                'page_parent'       => 'themes.php',            // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
                'page_permissions'  => 'manage_options',        // Permissions needed to access the options panel.
                'menu_icon'         => '',                      // Specify a custom URL to an icon
                'last_tab'          => '',                      // Force your panel to always open to a specific tab (by id)
                'page_icon'         => 'icon-themes',           // Icon displayed in the admin panel next to your menu_title
                'page_slug'         => '_options',              // Page slug used to denote the panel
                'save_defaults'     => true,                    // On load save the defaults to DB before user clicks save or not
                'default_show'      => false,                   // If true, shows the default value next to each field that is not the default value.
                'default_mark'      => '',                      // What to print by the field's title if the value shown is default. Suggested: *
                'show_import_export' => true,                   // Shows the Import/Export panel when not used as a field.
                
                // CAREFUL -> These options are for advanced use only
                'transient_time'    => 60 * MINUTE_IN_SECONDS,
                'output'            => true,                    // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
                'output_tag'        => true,                    // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
                // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.
                
                // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
                'database'              => '', // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
                'system_info'           => false, // REMOVE

                // HINTS
                'hints' => array(
                    'icon'          => 'icon-question-sign',
                    'icon_position' => 'right',
                    'icon_color'    => 'lightgray',
                    'icon_size'     => 'normal',
                    'tip_style'     => array(
                        'color'         => 'light',
                        'shadow'        => true,
                        'rounded'       => false,
                        'style'         => '',
                    ),
                    'tip_position'  => array(
                        'my' => 'top left',
                        'at' => 'bottom right',
                    ),
                    'tip_effect'    => array(
                        'show'          => array(
                            'effect'        => 'slide',
                            'duration'      => '500',
                            'event'         => 'mouseover',
                        ),
                        'hide'      => array(
                            'effect'    => 'slide',
                            'duration'  => '500',
                            'event'     => 'click mouseleave',
                        ),
                    ),
                )
            );


            // SOCIAL ICONS -> Setup custom links in the footer for quick links in your panel footer icons.
            $this->args['share_icons'][] = array(
                'url'   => 'https://github.com/ReduxFramework/ReduxFramework',
                'title' => 'Visit us on GitHub',
                'icon'  => 'el-icon-github'
                //'img'   => '', // You can use icon OR img. IMG needs to be a full URL.
            );
            $this->args['share_icons'][] = array(
                'url'   => 'https://www.facebook.com/pages/Redux-Framework/243141545850368',
                'title' => 'Like us on Facebook',
                'icon'  => 'el-icon-facebook'
            );
            $this->args['share_icons'][] = array(
                'url'   => 'http://twitter.com/reduxframework',
                'title' => 'Follow us on Twitter',
                'icon'  => 'el-icon-twitter'
            );
            $this->args['share_icons'][] = array(
                'url'   => 'http://www.linkedin.com/company/redux-framework',
                'title' => 'Find us on LinkedIn',
                'icon'  => 'el-icon-linkedin'
            );

            // Panel Intro text -> before the form
            if (!isset($this->args['global_variable']) || $this->args['global_variable'] !== false) {
                if (!empty($this->args['global_variable'])) {
                    $v = $this->args['global_variable'];
                } else {
                    $v = str_replace('-', '_', $this->args['opt_name']);
                }
                //$this->args['intro_text'] = sprintf(__('<p>Did you know that Redux sets a global variable for you? To access any of your saved options from within your code you can use your global variable: <strong>$%1$s</strong></p>', 'roadthemes'), $v);
            } else {
                //$this->args['intro_text'] = __('<p>This text is displayed above the options panel. It isn\'t required, but more info is always better! The intro_text field accepts all HTML.</p>', 'roadthemes');
            }

            // Add content after the form.
            //$this->args['footer_text'] = __('<p>This text is displayed below the options panel. It isn\'t required, but more info is always better! The footer_text field accepts all HTML.</p>', 'roadthemes');
        }

    }
    
    global $reduxConfig;
    $reduxConfig = new Road_Theme_Config();
}

/**
  Custom function for the callback referenced above
 */
if (!function_exists('redux_my_custom_field')):
    function redux_my_custom_field($field, $value) {
        print_r($field);
        echo '<br/>';
        print_r($value);
    }
endif;

/**
  Custom function for the callback validation referenced above
 * */
if (!function_exists('redux_validate_callback_function')):
    function redux_validate_callback_function($field, $value, $existing_value) {
        $error = false;
        $value = 'just testing';

        /*
          do your validation

          if(something) {
            $value = $value;
          } elseif(something else) {
            $error = true;
            $value = $existing_value;
            $field['msg'] = 'your custom error message';
          }
         */

        $return['value'] = $value;
        if ($error == true) {
            $return['error'] = $field;
        }
        return $return;
    }
endif;
